==> notolog-1.0.0-py3-none-any.whl: notolog/lexemes/tr/settings_dialog.py <==
# Turkish lexemes settings_dialog.py
lexemes = {
    "window_title": "Ayarlar",

    "button_close": "Kapat",

    "tab_general": "Genel",
    "tab_editor_config": "Editör",
    "tab_viewer_config": "Görüntüleyici",
    "tab_ai_config": "AI Ayarları",

    "general_app_config_label": "Uygulama ayarları",
    "general_app_language_label": "Dil",
    "general_app_language_combo_placeholder_text": "Bir dil seçin",
    "general_app_language_combo_accessible_description": "Uygulamanın arayüz dili",
    "general_app_theme_label": "Tema",
    "general_app_theme_combo_placeholder_text": "Bir tema seçin",
    "general_app_theme_combo_accessible_description": "Uygulamanın arayüz teması",
    "general_app_main_menu_label": "Ana Menü",
    "general_app_main_menu_checkbox": "Ana Menüyü Göster",
    "general_app_main_menu_checkbox_accessible_description": "Uygulamanın ana açılır menüsünü göster",
    "general_app_font_size_label": "Yazı Boyutu: {size}pt",
    "general_app_font_size_slider_accessible_description": "Uygulamanın genel yazı boyutunu ayarlayın",

    "general_statusbar_label": "Durum Çubuğu",
    "general_statusbar_show_global_cursor_position_checkbox": "Genel İmleç Pozisyonunu Göster",
    "general_statusbar_show_global_cursor_position_checkbox_accessible_description":
        "Durum çubuğunda genel imleç pozisyonunu göster",

    "editor_config_label": "Editör Yapılandırması",
    "editor_config_show_line_numbers_checkbox": "Satır Numaralarını Göster",
    "editor_config_show_line_numbers_checkbox_accessible_description": "Editörde satır numaralarını göster",

    "viewer_config_label": "Görüntüleyici Yapılandırması",
    "viewer_config_process_emojis_checkbox": "Metin Emojilerini Grafiklere Dönüştür",
    "viewer_config_process_emojis_checkbox_accessible_description": "Metin emojilerini grafiksel temsillere dönüştür",
    "viewer_config_highlight_todos_checkbox": "TODO'ları Vurgula",
    "viewer_config_highlight_todos_checkbox_accessible_description": "Metindeki TODO etiketlerini vurgula",
    "viewer_config_open_link_confirmation_checkbox": "Bağlantıları Açmadan Önce Onay İste",
    "viewer_config_open_link_confirmation_checkbox_accessible_description": "Bağlantıları açmadan önce onay isteyin",
    "viewer_config_save_resources_checkbox": "Dış Resimleri Diskte Otomatik Kaydet",
    "viewer_config_save_resources_checkbox_accessible_description":
        "Dış resimlerin kopyalarını çevrimdışı erişim için diske otomatik olarak kaydet",

    "ai_config_inference_module_label": "Çıkarım modülü",
    "ai_config_inference_module_names_combo_placeholder_text": "Modül seç",
    "ai_config_inference_module_names_combo_accessible_description": "Seçilebilecek modüller",

    "ai_config_multi_turn_dialogue_checkbox":
        "Önceki isteklere dayanan bağlamsal sürekliliği sağlayan çok turlu diyalog",
    "ai_config_multi_turn_dialogue_checkbox_accessible_description":
        "Önceki isteklere dayanan bağlamsal sürekliliği sağlayan çok turlu diyalog",
    "ai_config_convert_to_md_checkbox": "Sonucu Markdown'a çevir",
    "ai_config_convert_to_md_checkbox_accessible_description": "Sonuç mesajını Markdown'a çevir",

    "ai_config_base_label": "Temel Parametreler",
}

==> notolog-1.0.7-py3-none-any.whl: notolog/lexemes/tr/settings_dialog.py <==
# Turkish lexemes settings_dialog.py
lexemes = {
    "window_title": "Ayarlar",

    "button_close": "Kapat",

    "tab_general": "Genel",
    "tab_editor_config": "Editör",
    "tab_viewer_config": "Görüntüleyici",
    "tab_ai_config": "AI Ayarları",

    "general_app_config_label": "Uygulama ayarları",
    "general_app_language_label": "Dil",
    "general_app_language_combo_placeholder_text": "Bir dil seçin",
    "general_app_language_combo_accessible_description": "Uygulamanın arayüz dili",
    "general_app_theme_label": "Tema",
    "general_app_theme_combo_placeholder_text": "Bir tema seçin",
    "general_app_theme_combo_accessible_description": "Uygulamanın arayüz teması",
    "general_app_main_menu_label": "Ana Menü",
    "general_app_main_menu_checkbox": "Ana Menüyü Göster",
    "general_app_main_menu_checkbox_accessible_description": "Uygulamanın ana açılır menüsünü göster",
    "general_app_font_size_label": "Yazı Boyutu: {size}pt",
    "general_app_font_size_slider_accessible_description": "Uygulamanın genel yazı boyutunu ayarlayın",

    "general_statusbar_label": "Durum Çubuğu",
    "general_statusbar_show_global_cursor_position_checkbox": "Genel İmleç Pozisyonunu Göster",
    "general_statusbar_show_global_cursor_position_checkbox_accessible_description":
        "Durum çubuğunda genel imleç pozisyonunu göster",

    "editor_config_label": "Editör Yapılandırması",
    "editor_config_show_line_numbers_checkbox": "Satır Numaralarını Göster",
    "editor_config_show_line_numbers_checkbox_accessible_description": "Editörde satır numaralarını göster",

    "viewer_config_label": "Görüntüleyici Yapılandırması",
    "viewer_config_process_emojis_checkbox": "Metin Emojilerini Grafiklere Dönüştür",
    "viewer_config_process_emojis_checkbox_accessible_description": "Metin emojilerini grafiksel temsillere dönüştür",
    "viewer_config_highlight_todos_checkbox": "TODO'ları Vurgula",
    "viewer_config_highlight_todos_checkbox_accessible_description": "Metindeki TODO etiketlerini vurgula",
    "viewer_config_open_link_confirmation_checkbox": "Bağlantıları Açmadan Önce Onay İste",
    "viewer_config_open_link_confirmation_checkbox_accessible_description": "Bağlantıları açmadan önce onay isteyin",
    "viewer_config_save_resources_checkbox": "Dış Resimleri Diskte Otomatik Kaydet",
    "viewer_config_save_resources_checkbox_accessible_description":
        "Dış resimlerin kopyalarını çevrimdışı erişim için diske otomatik olarak kaydet",

    "ai_config_inference_module_label": "Çıkarım Modülü",
    "ai_config_inference_module_names_combo_label": "Aktif Çıkarım Modülü",
    "ai_config_inference_module_names_combo_placeholder_text": "Modül Seçin",
    "ai_config_inference_module_names_combo_accessible_description":
        "AI Asistanı ile çalışacak mevcut AI çıkarım modüllerinden seçim yapın.\n"
        "Seçenekler, gerçek zamanlı işleme sahip büyük dil modelleri (LLM) veya API tabanlı işlevselliği içerir.",

    "ai_config_base_label": "Temel Parametreler",
    "ai_config_multi_turn_dialogue_checkbox": "Konuşma hafızasına sahip çok dönüşlü diyalog",
    "ai_config_multi_turn_dialogue_checkbox_accessible_description":
        "Konuşma hafızası için önceki istemi koruyan çok dönüşlü diyaloğu etkinleştirin.\n"
        "Devre dışı bırakıldığında, yalnızca yeni mesaj ve sistem istemi yanıtı etkiler.",
    "ai_config_convert_to_md_checkbox": "Sonucu Markdown'a Dönüştür",
    "ai_config_convert_to_md_checkbox_accessible_description":
        "Çıkış mesajını Markdown formatına dönüştürün.",
}
